/*
 * Minimalizacja funkcji wielu zmiennych ("Projekt systemu")
 * Bartlomiej Brzozowiec, VIII 2005
 */
//---------------------------------------------------------------------------
// klasa implementujaca met. Hooka-Jeevsa (s. 187 w: Findeisen, Szymanowski, Wierzbicki -
// "Teoria i metody obliczeniowe optymalizacji" ("timoo"), PWN, W-wa 1977)
// ((tu i owdzie sa lamane zasady calkowitej enkapsulacji - wyszukaj "Form1"))

/*
 * przykladowe wartosci:
 *
 * il. zm.: 2
 * funkcja: (-sin(sqrt(x1*x1+x2*x2)))/(sqrt(x1*x1+x2*x2))
 * x1 = -.1
 * x2 = .1
 * tau     = 0.0001
 * beta    = 0.5
 * epsilon = 0.00000000001
 * (spodziewany wynik: f( 0., 0. ) = -1
 * --
 * il. zm.: 2
 * funkcja: -exp(-( (0.1x1)^2+(0.3x2)^2 ))
 * x1 = -5
 * x2 = 2
 * tau     = (j.w.)
 * beta    = (j.w.)
 * epsilon = (j.w.)
 * (spodziewany wynik: f( 0., 0. ) = -1
  * --
 * il. zm.: 1
 * funkcja: -sin(abs(x1))/abs(x1)
 * x1 = -2.5
 * tau     = (j.w.)
 * beta    = (j.w.)
 * epsilon = (j.w.)
 * (spodziewany wynik: f( 0 ) = -1
 */

#ifndef _HOOKJEEVES_H
#define _HOOKJEEVES_H

#include <valarray>
#include "MetodaMinim.h"
#include "Unit1.h"

class HookJeeves : public MetodaMinim {
        private:
                // zmienne
                int n_wymiar; // dlugosc wektora
                double tau, beta, epsilon;
                std::valarray<double>   x0, // punkt startowy
                                        d; // 'macierz' wersorow
                // metody
                bool pobierz_t_b_e( void );
                void wypelnij_x0( void );
                bool metoda( void );
        public:
                // konstruktor
                HookJeeves();

                void OKilzm();
                bool Licz();
                void Posprzataj();
};

#endif
